## Description

<!-- Briefly describe what this PR does -->

## Related Issue

<!-- Link to related issue: Fixes #123 -->

## Type of Change

- [ ] Bug fix (non-breaking change that fixes an issue)
- [ ] New feature (non-breaking change that adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Refactoring
- [ ] Other: <!-- describe -->

## Checklist

- [ ] I have tested my changes locally
- [ ] Tests pass: `pytest tests/ -v`
- [ ] Code follows the style guidelines (PEP 8)
- [ ] Documentation has been updated (if applicable)
- [ ] Commits are properly formatted

## Additional Notes

<!-- Add any additional context about the PR -->
